--[[
	Inclusion of WoD data, and other tips I found necessary
	Modified by AnthonyG70 (Bogdan-Proudmoore)
    Thanks to Zenh for Needy; their release has not been updated since 2010.
	Rap_Sheet ver 2.2
	Created APR 2013, Last update 11 MAR 2015
]]

-- CONFIGURATION START
-- change from true to false to hide data output

local options = {
    showRespecs = true,
    showDualSpec = true,
    showLevel = true,
	showScore = true,
	showHK = true,
	showBgs = true,
	showBosses = true,
    showInCombat = false,
	showCounts = true
}

-- CONFIGURATION END

local ids = {
    rollsGreed = 1043,
    rollsNeed = 1044,
--	rollsDE = 181,
    respecNum = 1149,
    dualSpec = 2716,
    maxLevel = 9060,
-- PvP
	honorKills = 588,
	bgsPlayed = 839,
	arenaWins = 837,
	arenaTwo = 370,
	arenaThree = 595,
	arenaFive = 596,
	arenaThreeTeam = 590,
	arenaTwoTeam = 374,
--	Highmaul End Boss
	bossLMargokKills = 9312,
	bossMargokKills = 9313,
	bossHMargokKills = 9314,
	bossMMargokKills = 9315,
	bossMargokDate = 8988,
	bossMMargokDate = 8965,
--	Blackrock Foundry End Boss
	bossLBlackhandKills = 9362,
	bossBlackhandKills = 9363,
	bossHBlackhandKills = 9364,
	bossMBlackhandKills = 9365,
	bossBlackhandDate = 8992,
	bossMBlackhandDate = 8973
}

CreateFrame('Frame', 'RapSheet', UIParent)

RapSheet:SetScript('OnEvent', function(self, event, ...) self[event](self, ...) end)
RapSheet:RegisterEvent('MODIFIER_STATE_CHANGED')

if TinyTip then
    TinyTip.HookOnTooltipSetUnit(GameTooltip, RapSheet.UPDATE_MOUSEOVER_UNIT)
else
    RapSheet:RegisterEvent('UPDATE_MOUSEOVER_UNIT')
end

-- Inspect Achievements

function RapSheet:INSPECT_ACHIEVEMENT_READY()
    self:UnregisterEvent('INSPECT_ACHIEVEMENT_READY')
    self.line:SetText()

    if GameTooltip:GetUnit() == self.unit then
        local stats, text = {}, ''

        stats.needs = tonumber(GetComparisonStatistic(ids.rollsNeed)) or 0
        stats.greeds = tonumber(GetComparisonStatistic(ids.rollsGreed)) or 0
		
		stats.honorablekills = tonumber(GetComparisonStatistic(ids.honorKills)) or 0
		
        stats.respecNum = GetComparisonStatistic(ids.respecNum)
        stats.dualSpec = GetAchievementComparisonInfo(ids.dualSpec)
		
		stats.bgsPlayed = tonumber(GetComparisonStatistic(ids.bgsPlayed)) or 0
		stats.arenaWins = tonumber(GetComparisonStatistic(ids.arenaWins)) or 0
		stats.arenaTwo = tonumber(GetComparisonStatistic(ids.arenaTwo)) or 0
		stats.arenaThree = tonumber(GetComparisonStatistic(ids.arenaThree)) or 0
		stats.arenaFive = tonumber(GetComparisonStatistic(ids.arenaFive)) or 0
		stats.arenaThreeTeam = tonumber(GetComparisonStatistic(ids.arenaThreeTeam)) or 0
		stats.arenaTwoTeam = tonumber(GetComparisonStatistic(ids.arenaTwoTeam)) or 0
		
		stats.bossLMargokKills = GetComparisonStatistic(ids.bossLMargokKills)
		stats.bossMargokKills = GetComparisonStatistic(ids.bossMargokKills)
		stats.bossHMargokKills = GetComparisonStatistic(ids.bossHMargokKills)
		stats.bossMMargokKills = GetComparisonStatistic(ids.bossMMargokKills)
		
		stats.bossLBlackhandKills = GetComparisonStatistic(ids.bossLBlackhandKills)
		stats.bossBlackhandKills = GetComparisonStatistic(ids.bossBlackhandKills)
		stats.bossHBlackhandKills = GetComparisonStatistic(ids.bossHBlackhandKills)
		stats.bossMBlackhandKills = GetComparisonStatistic(ids.bossMBlackhandKills)
		
-- check boss dates Highmaul

        if options.showBosses then
            local completed, month, day, year = GetAchievementComparisonInfo(ids.bossMargokDate)

            if completed then
                year = year < 10 and 0 .. year or year
                day = day < 10 and 0 .. day or day
            end

            stats.bossMargokDate = completed and month .. '/' .. day .. '/' .. year or '|cffff0000None'
		end
		
        if options.showBosses then
            local completed, month, day, year = GetAchievementComparisonInfo(ids.bossMMargokDate)

            if completed then
                year = year < 10 and 0 .. year or year
                day = day < 10 and 0 .. day or day
            end

            stats.bossMMargokDate = completed and month .. '/' .. day .. '/' .. year or '|cffff0000None'
        end

-- check boss dates Blackrock Foundry
		
        if options.showBosses then
            local completed, month, day, year = GetAchievementComparisonInfo(ids.bossBlackhandDate)

            if completed then
                year = year < 10 and 0 .. year or year
                day = day < 10 and 0 .. day or day
            end

            stats.bossBlackhandDate = completed and month .. '/' .. day .. '/' .. year or '|cffff0000None'
		end
		
        if options.showBosses then
			local completed, month, day, year = GetAchievementComparisonInfo(ids.bossMBlackhandDate)

            if completed then
                year = year < 10 and 0 .. year or year
                day = day < 10 and 0 .. day or day
            end

            stats.bossMBlackhandDate = completed and month .. '/' .. day .. '/' .. year or '|cffff0000None'
        end

-- Verify level 100 account wide

        if options.showLevel then
            local completed, month, day, year = GetAchievementComparisonInfo(ids.maxLevel)

            if completed then
                year = year < 10 and 0 .. year or year
                day = day < 10 and 0 .. day or day
            end

            stats.levelhundred = completed and month .. '/' .. day .. '/' .. year or '|cffff0000No Lvl 100 toons'
        end

-- math for greed/need stats
		
        if stats.needs > 0 then
            percentNeeds = math.floor((stats.needs / (stats.greeds + stats.needs)) * 100)
            text = text .. '\n|cFFF1C502Needs:  |cFFFFFFFF' .. (percentNeeds > 50 and '|cFFFF0000' .. percentNeeds or percentNeeds) .. '%  (' .. stats.needs .. ')'
        else
            percentNeeds = 0
        end

-- Ctrl pressed, then show full sheet
		
        if IsControlKeyDown() then
            if stats.greeds > 0 then
                percentGreeds = 100 - percentNeeds
                text = text .. '\n|cFFF1C502Greeds:  |cFFFFFFFF' .. (percentGreeds > 50 and '|cFF00FF00' .. percentGreeds or percentGreeds) .. '%  (' .. stats.greeds .. ')'
            end

            if options.showRespecs and UnitLevel('mouseover') >= 10 then
                text = text .. '\n|cFFF1C502Respecs:  |cFFFFFFFF' .. (stats.respecNum == '--' and 'None' or stats.respecNum)
            end

            if options.showDualSpec and UnitLevel('mouseover') >= 40 then
                text = text .. '\n|cFFF1C502Dual Spec:  |cFFFFFFFF' .. (stats.dualSpec and 'Yes' or 'No')
            end
			
			if options.showHK and stats.honorablekills > 0 then
				text = text .. '\n|cFFF1C502HKs:  |cFFFFFFFF' .. stats.honorablekills
			end
			
			if options.showBgs then
				text = text .. '\n \n|cff00ff00--- PvP Info |cFFFFFFFF'
			end
			if options.showBgs then
				text = text .. '\n|cFFF1C502BGs played:  |cFFFFFFFF' .. stats.bgsPlayed
			end
			
			if options.showScore then
				text = text .. '\n \n|cff00ff00--- Arena Info |cFFFFFFFF'
			end
			if options.showScore and stats.arenaWins > 0 then
				text = text .. '\n|cFFF1C502Arena Wins:  |cFFFFFFFF' .. stats.arenaWins
			end
			if options.showScore and stats.arenaTwo > 0 then
				text = text .. '\n|cFFF1C5022 Man Personal Rating:  |cFFFFFFFF' .. stats.arenaTwo
			end
			if options.showScore and stats.arenaThree > 0 then
				text = text .. '\n|cFFF1C5023 Man Personal Rating:  |cFFFFFFFF' .. stats.arenaThree
			end
			if options.showScore and stats.arenaFive > 0 then
				text = text .. '\n|cFFF1C5025 Man Personal Rating:  |cFFFFFFFF' .. stats.arenaFive
			end
			if options.showScore and stats.arenaTwoTeam > 0 then
			text = text .. '\n|cFFF1C5022 Man Team Rating:  |cFFFFFFFF' .. stats.arenaTwoTeam
			end
			if options.showScore and stats.arenaThreeTeam > 0 then
			text = text .. '\n|cFFF1C5023 Man Team Rating:  |cFFFFFFFF' .. stats.arenaThreeTeam
			end

-- show current content boss kills

			if options.showCounts then
			text = text .. '\n \n|cff00ff00--- Raid Info |cFFFFFFFF'
			text = text .. '\n|cFFF1C502Margok Kills'
				text = text .. '\n|cff40c840LFR: ' .. (stats.bossLMargokKills == '--' and '0' or  stats.bossLMargokKills) .. '|cffffffff / ' .. '|cff206edcNorm: ' .. (stats.bossMargokKills == '--' and '0' or stats.bossMargokKills)  .. '|cffffffff / ' .. '|cffc030c0 Hero: ' .. (stats.bossHMargokKills == '--' and '0' or stats.bossHMargokKills)  .. '|cffffffff / ' .. '|cffff8000 Mythic: ' .. (stats.bossMMargokKills == '--' and '0' or stats.bossMMargokKills)

			text = text .. '\n|cFFF1C502Blackhand Kills'
				text = text .. '\n|cff40c840LFR: ' .. (stats.bossLBlackhandKills == '--' and '0' or  stats.bossLBlackhandKills) .. '|cffffffff / ' .. '|cff206edcNorm: ' .. (stats.bossBlackhandKills == '--' and '0' or stats.bossBlackhandKills)  .. '|cffffffff / ' .. '|cffc030c0 Hero: ' .. (stats.bossHBlackhandKills == '--' and '0' or stats.bossHBlackhandKills)  .. '|cffffffff / ' .. '|cffff8000 Mythic: ' .. (stats.bossMBlackhandKills == '--' and '0' or stats.bossMBlackhandKills)			
			end

 -- account wide info		
			
			text = text .. '\n \n|cff00ff00--- Account Wide |cFFFFFFFF'

            if options.showLevel then
                text = text .. '\n|cFFF1C502Level 100 Credit:  |cFFFFFFFF' .. stats.levelhundred
            end

-- current boss kill credits

			if options.showBosses then
				text = text .. '\n'
				text = text .. '\n|cFFF1C502Margok Kill Credit:  |cFFFFFFFF' .. stats.bossMargokDate
				text = text .. '\n|cFFF1C502Mythic Margok Kill Credit:  |cFFFFFFFF' .. stats.bossMMargokDate
				
				text = text .. '\n|cFFF1C502Blackhand Kill Credit:  |cFFFFFFFF' .. stats.bossBlackhandDate
				text = text .. '\n|cFFF1C502Mythic Blackhand Kill Credit:  |cFFFFFFFF' .. stats.bossMBlackhandDate
            end

       end

        if text ~= '' then
            self.line:SetText(text)
        end
    end

    GameTooltip:Show()

    if not UnitName('mouseover') then
        GameTooltip:FadeOut()
    end

-- cleanup achievement lookup
	
    ClearAchievementComparisonUnit()

    if _G.GearScore then
        _G.GearScore:RegisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    if Elite then
        Elite:RegisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    if AchievementFrameComparison then
        AchievementFrameComparison:RegisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    self:RegisterEvent('UPDATE_MOUSEOVER_UNIT')
end

-- look for shifted key type

function RapSheet:MODIFIER_STATE_CHANGED()
    if arg1 == 'LCTRL' or arg1 == 'RCTRL' then
        if self.line and UnitName('mouseover') == self.unit then
            self:UPDATE_MOUSEOVER_UNIT(true)
        end
    end
end

-- refresh

function RapSheet:UPDATE_MOUSEOVER_UNIT(refresh)
    if not refresh then
        self.unit, self.line = nil, nil
    end

    if (not options.showInCombat and UnitAffectingCombat('player')) or UnitIsDead('player') or not UnitExists('mouseover')
    or not UnitIsPlayer('mouseover') or not UnitIsConnected('mouseover') or UnitIsDead('mouseover') then
        return
    end

    self.unit = UnitName('mouseover')

    local text = '\nRap Sheep - working..'

    if refresh then
        self.line:SetText(text)
    else
        GameTooltip:AddLine(text)
        self.line = _G['GameTooltipTextLeft' .. GameTooltip:NumLines()]
    end

    GameTooltip:Show()

    if _G.GearScore then
        _G.GearScore:UnregisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    if Elite then
        Elite:UnregisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    if AchievementFrameComparison then
        AchievementFrameComparison:UnregisterEvent('INSPECT_ACHIEVEMENT_READY')
    end

    self:UnregisterEvent('UPDATE_MOUSEOVER_UNIT')
    self:RegisterEvent('INSPECT_ACHIEVEMENT_READY')

    SetAchievementComparisonUnit('mouseover')
end